@@ -1,4 +1,4 @@
-# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,12 +10,14 @@ package Devel::Cover;
 use strict;
 use warnings;
 
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '1.08'; # VERSION
 our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
 
 use DynaLoader ();
 our @ISA = "DynaLoader";
 
+# sub Pod::Coverage::TRACE_ALL () { 1 }
+
 use Devel::Cover::DB;
 use Devel::Cover::DB::Digests;
 use Devel::Cover::Inc;
@@ -26,10 +28,11 @@ use B::Deparse;
 
 use Carp;
 use Config;
-use Cwd "abs_path";
+use Cwd qw" abs_path getcwd ";
 use File::Spec;
 
 use Devel::Cover::Dumper;
+use Devel::Cover::Util 'remove_contained_paths';
 
 BEGIN
 {
@@ -68,6 +71,7 @@ my $Pod = $INC{"Pod/Coverage/CountParents.pm"} ? "Pod::Coverage::CountParents" :
 my %Pod;                                 # Pod coverage data.
 
 my @Cvs;                                 # All the Cvs we want to cover.
+my %Cvs;                                 # All the Cvs we want to cover.
 my @Subs;                                # All the subs we want to cover.
 my $Cv;                                  # Cv we are looking in.
 my $Sub_name;                            # Name of the sub we are looking in.
@@ -105,25 +109,46 @@ BEGIN
               ($ENV{PERL5OPT}              || "") =~ /Devel::Cover/;
     *OUT = $ENV{DEVEL_COVER_DEBUG} ? *STDERR : *STDOUT;
 
-    eval
+    if ($^X =~ /(apache2|httpd)$/)
     {
-        local %ENV = %ENV;
-        # Clear *PERL* variables, but keep PERL5?LIB for local::lib environments
-        /perl/i and !/^PERL5?LIB$/ and delete $ENV{$_} for keys %ENV;
-        my $cmd = "$^X -MData::Dumper -e " . '"print Dumper \@INC"';
-        my $VAR1;
-        # print STDERR "Running [$cmd]\n";
-        eval `$cmd`;
-        @Inc = @$VAR1;
-    };
-    if ($@)
-    {
-        print STDERR __PACKAGE__, ": Error getting \@INC: $@\n",
-                                  "Reverting to default value for Inc.\n";
+        # mod_perl < 2.0.8
         @Inc = @Devel::Cover::Inc::Inc;
     }
+    else
+    {
+        # Can't get @INC via eval `` in taint mode, revert to default value.
+        if (${^TAINT})
+        {
+            @Inc = @Devel::Cover::Inc::Inc;
+        }
+        else
+        {
+            eval
+            {
+                local %ENV = %ENV;
+                # Clear *PERL* variables, but keep PERL5?LIB for local::lib
+                # environments
+                /perl/i and !/^PERL5?LIB$/ and delete $ENV{$_} for keys %ENV;
+                my $cmd = "$^X -MData::Dumper -e " . '"print Dumper \@INC"';
+                my $VAR1;
+                # print STDERR "Running [$cmd]\n";
+                eval `$cmd`;
+                @Inc = @$VAR1;
+            };
+            if ($@)
+            {
+                print STDERR __PACKAGE__,
+                             ": Error getting \@INC: $@\n",
+                             "Reverting to default value for Inc.\n";
+                @Inc = @Devel::Cover::Inc::Inc;
+            }
+        }
+    }
+
     @Inc = map { -d $_ ? ($_ eq "." ? $_ : Cwd::abs_path($_)) : () } @Inc;
 
+    @Inc = remove_contained_paths(getcwd, @Inc);
+
     @Ignore = ("/Devel/Cover[./]") unless $Self_cover = $ENV{DEVEL_COVER_SELF};
     # $^P = 0x004 | 0x010 | 0x100 | 0x200;
     # $^P = 0x004 | 0x100 | 0x200;
@@ -547,12 +572,20 @@ my $find_filename = qr/
 
 sub use_file
 {
+    # If we're in global destruction, forget it.
+    return unless $find_filename;
+
     my ($file) = @_;
 
     # print STDERR "use_file($file)\n";
 
     # die "bad file" unless length $file;
 
+    # If you call your file something that matches $find_filename then things
+    # might go awry.  But it would be silly to do that, so don't.  This little
+    # optimisation provides a reasonable speedup.
+    return $Files{$file} if exists $Files{$file};
+
     # just don't call your filenames 0
     while ($file =~ $find_filename) { $file = $1 || $2 || $3 || $4 }
     $file =~ s/ \(autosplit into .*\)$//;
@@ -579,6 +612,7 @@ sub use_file
         unless $Files{$file} || $Silent
                              || $file =~ $Devel::Cover::DB::Ignore_filenames;
 
+    add_cvs();  # add CVs now in case of symbol table manipulation
     $Files{$file}
 }
 
@@ -604,22 +638,26 @@ sub B::GV::find_cv
     return unless $$cv;
 
     # print STDERR "find_cv $$cv\n" if check_file($cv);
-    push @Cvs, $cv if check_file($cv);
-    push @Cvs, grep check_file($_), $cv->PADLIST->ARRAY->ARRAY
-        if $cv->can("PADLIST") &&
-           $cv->PADLIST->can("ARRAY") &&
-           $cv->PADLIST->ARRAY &&
-           $cv->PADLIST->ARRAY->can("ARRAY");
+    $Cvs{$cv} ||= $cv if check_file($cv);
+    if ($cv->can("PADLIST") &&
+        $cv->PADLIST->can("ARRAY") &&
+        $cv->PADLIST->ARRAY &&
+        $cv->PADLIST->ARRAY->can("ARRAY"))
+    {
+        $Cvs{$_} ||= $_
+          for grep ref eq "B::CV" && check_file($_), $cv->PADLIST->ARRAY->ARRAY;
+    }
 };
 
 sub sub_info
 {
     my ($cv) = @_;
     my ($name, $start) = ("--unknown--", 0);
-    if (!$cv->GV->isa("B::SPECIAL"))
+    my $gv = $cv->GV;
+    if ($gv && !$gv->isa("B::SPECIAL"))
     {
-        return unless $cv->GV->can("SAFENAME");
-        $name = $cv->GV->SAFENAME;
+        return unless $gv->can("SAFENAME");
+        $name = $gv->SAFENAME;
         # print STDERR "--[$name]--\n";
         $name =~ s/(__ANON__)\[.+:\d+\]/$1/ if defined $name;
     }
@@ -641,11 +679,16 @@ sub sub_info
     ($name, $start)
 }
 
+sub add_cvs
+{
+    $Cvs{$_} ||= $_ for grep check_file($_), B::main_cv->PADLIST->ARRAY->ARRAY;
+}
+
 sub check_files
 {
     # print STDERR "Checking files\n";
 
-    @Cvs = grep check_file($_), B::main_cv->PADLIST->ARRAY->ARRAY;
+    add_cvs();
 
     my %seen_pkg;
     my %seen_cv;
@@ -667,11 +710,13 @@ sub check_files
         ($line, $name)
     };
 
+    # print Dumper \%Cvs;
+
     @Cvs = map  $_->[0],
            sort { $a->[1] <=> $b->[1] || $a->[2] cmp $b->[2] }
            map  [ $_, $l->($_) ],
            grep !$seen_cv{$$_}++,
-           @Cvs;
+           values %Cvs;
 
     # Hack to bump up the refcount of the subs.  If we don't do this then the
     # subs in some modules don't seem to be around when we get to looking at
@@ -711,6 +756,7 @@ EOM
 sub _report
 {
     local @SIG{qw(__DIE__ __WARN__)};
+    # $SIG{__DIE__} = \&Carp::confess;
 
     $Run{finish} = get_elapsed() / 1e6;
 
@@ -718,7 +764,6 @@ sub _report
         "did you require instead of use Devel::Cover?\n"
         unless defined $Dir;
 
-
     my @collected = get_coverage();
     return unless @collected;
     set_coverage("none") unless $Self_cover;
@@ -933,7 +978,7 @@ sub add_condition_cover
         my $name = $r->name;
         $name = $r->first->name if $name eq "sassign";
         # TODO - exec?  any others?
-        # print STDERR "Name [$name]\n";
+        # print STDERR "Name [$name]", Dumper $c;
         if ($c->[5] || $name =~ $Const_right)
         {
             $c = [ $c->[3], $c->[1] + $c->[2] ];
@@ -945,7 +990,7 @@ sub add_condition_cover
             @$c = @{$c}[$type eq "or" ? (3, 2, 1) : (3, 1, 2)];
             $count = 3;
         }
-        # print STDERR "$type 3 $name [@$c] $File:$Line\n";
+        # print STDERR "$type 3 $name [", join(",", @$c), "] $File:$Line\n";
     }
     elsif ($type eq "xor")
     {
@@ -1009,14 +1054,20 @@ sub deparse
 
         my $name = $op->can("name") ? $op->name : "Unknown";
 
-        # print STDERR "$class:$name at $File:$Line\n";
+        # print STDERR "$class:$name ($$op) at $File:$Line\n";
+        # print STDERR "[$Seen{statement}{$$op}] [$Seen{other}{$$op}]\n";
+        # use Carp "cluck"; cluck("from here");
 
-        {
+        return "" if $name eq "padrange";
+
+        unless ($Seen{statement}{$$op} || $Seen{other}{$$op}) {
             # Collect everything under here.
             local ($File, $Line) = ($File, $Line);
+            # print STDERR "Collecting $$op under $File:$Line\n";
             $deparse = eval { local $^W; $Original{deparse}->($self, @_) };
             $deparse =~ s/^\010+//mg if defined $deparse;
             $deparse = "Deparse error: $@" if $@;
+            # print STDERR "Collected $$op under $File:$Line\n";
             # print STDERR "Collect Deparse $op $$op => <$deparse>\n";
         }
 
@@ -1024,6 +1075,7 @@ sub deparse
 
         if ($class eq "COP" && $Coverage{statement})
         {
+            # print STDERR "COP $$op, seen [$Seen{statement}{$$op}]\n";
             add_statement_cover($op) unless $Seen{statement}{$$op}++;
         }
         elsif (!$null && $name eq "null"
@@ -1034,11 +1086,13 @@ sub deparse
             # get at the file and line number, but we need to get dirty.
 
             bless $op, "B::COP";
+            # print STDERR "null $$op, seen [$Seen{statement}{$$op}]\n";
             add_statement_cover($op) unless $Seen{statement}{$$op}++;
             bless $op, "B::$class";
         }
         elsif ($Seen{other}{$$op}++)
         {
+            # print STDERR "seen [$Seen{other}{$$op}]\n";
             return ""  # Only report on each op once.
         }
         elsif ($name eq "cond_expr")
@@ -1081,12 +1135,16 @@ sub deparse
     else
     {
         local ($File, $Line) = ($File, $Line);
+        # print STDERR "Starting plain deparse at $File:$Line\n";
         $deparse = eval { local $^W; $Original{deparse}->($self, @_) };
-        $deparse =~ s/^\010+//mg if defined $deparse;
+        $deparse = "" unless defined $deparse;
+        $deparse =~ s/^\010+//mg;
         $deparse = "Deparse error: $@" if $@;
+        # print STDERR "Ending plain deparse at $File:$Line\n";
         # print STDERR "Deparse => <$deparse>\n";
     }
 
+    # print STDERR "Returning [$deparse]\n";
     $deparse
 }
 
@@ -1213,9 +1271,10 @@ sub get_cover
 
     if ($Pod && $Coverage{pod})
     {
-        unless ($cv->GV->isa("B::SPECIAL"))
+        my $gv = $cv->GV;
+        if ($gv && !$gv->isa("B::SPECIAL"))
         {
-            my $stash = $cv->GV->STASH;
+            my $stash = $gv->STASH;
             my $pkg   = $stash->NAME;
             my $file  = $cv->FILE;
             my %opts;
@@ -1241,21 +1300,24 @@ sub get_cover
                 }
             }
             $Pod = "Pod::Coverage" if delete $opts{nocp};
-            # print STDERR "$Pod, ", Dumper \%opts;
-            if ($Pod{$file} ||= $Pod->new(package => $pkg, %opts))
+            # print STDERR "$Pod, $File:$Line ($Sub_name) [$file($pkg)]",
+            #              Dumper \%opts;
+            if ($Pod{$pkg} ||= $Pod->new(package => $pkg, %opts))
             {
+                # print STDERR Dumper $Pod{$file};
                 my $covered;
-                for ($Pod{$file}->covered)
+                for ($Pod{$pkg}->covered)
                 {
                     $covered = 1, last if $_ eq $Sub_name;
                 }
                 unless ($covered)
                 {
-                    for ($Pod{$file}->uncovered)
+                    for ($Pod{$pkg}->uncovered)
                     {
                         $covered = 0, last if $_ eq $Sub_name;
                     }
                 }
+                # print STDERR "covered ", $covered // "undef", "\n";
                 if (defined $covered)
                 {
                     my ($n, $new) = $Structure->add_count("pod");
@@ -1288,7 +1350,10 @@ sub get_cover
     $de
 }
 
-1
+"
+We have normality, I repeat we have normality.
+Anything you still can’t cope with is therefore your own problem.
+"
 
 __END__
 
@@ -1298,7 +1363,7 @@ Devel::Cover - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 0.93
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -1312,7 +1377,7 @@ or
  HARNESS_PERL_SWITCHES=-MDevel::Cover make test
  cover
 
-To get coverage for an uninstalled module which uses Module::Build (0.26 or
+To get coverage for an uninstalled module which uses L<Module::Build> (0.26 or
 later):
 
  ./Build testcover
@@ -1326,6 +1391,8 @@ If you want to get coverage for a program:
  perl -MDevel::Cover yourprog args
  cover
 
+To alter default values:
+
  perl -MDevel::Cover=-db,cover_db,-coverage,statement,time yourprog args
 
 =head1 DESCRIPTION
@@ -1333,19 +1400,18 @@ If you want to get coverage for a program:
 This module provides code coverage metrics for Perl.  Code coverage metrics
 describe how thoroughly tests exercise code.  By using Devel::Cover you can
 discover areas of code not exercised by your tests and determine which tests
-to create to increase coverage.  Code coverage can be considered as an
-indirect measure of quality.
+to create to increase coverage.  Code coverage can be considered an indirect
+measure of quality.
 
 Although it is still being developed, Devel::Cover is now quite stable and
 provides many of the features to be expected in a useful coverage tool.
 
 Statement, branch, condition, subroutine, and pod coverage information is
-reported.  Statement coverage data should be reasonable.  Branch and condition
-coverage data should be mostly accurate too, although not always what one
-might initially expect.  Subroutine coverage should be as accurate as
-statement coverage.  Pod coverage comes from L<Pod::Coverage>.  If
-L<Pod::Coverage::CountParents> is available it will be used instead.  Coverage
-data for other criteria are not yet collected.
+reported.  Statement and subroutine coverage data should be accurate.  Branch
+and condition coverage data should be mostly accurate too, although not always
+what one might initially expect.  Pod coverage comes from L<Pod::Coverage>.
+If L<Pod::Coverage::CountParents> is available it will be used instead.
+Coverage data for other criteria are not yet collected.
 
 The F<cover> program can be used to generate coverage reports.  Devel::Cover
 ships with a number of different reports including various types of HTML
@@ -1353,36 +1419,31 @@ output, textual reports, a report to display missing coverage in the same
 format as compilation errors and a report to display coverage information
 within the Vim editor.
 
-It is possible to add annotations to reports, for example you could add a
-column to an HTML report showing who last changed a line, as determined by git
-blame.  Some annotation modules are shipped with Devel::Cover and you can
-easily create your own.
+It is possible to add annotations to reports, for example you can add a column
+to an HTML report showing who last changed a line, as determined by git blame.
+Some annotation modules are shipped with Devel::Cover and you can easily
+create your own.
 
 The F<gcov2perl> program can be used to convert gcov files to C<Devel::Cover>
 databases.  This allows you to display your C or XS code coverage together
-with your Perl coverage, or to use any of the Devel::Cvoer reports to display
+with your Perl coverage, or to use any of the Devel::Cover reports to display
 your C coverage data.
 
-You may find that the coverage results don't match your expectations.  This
-could be due to a bug in Devel::Cover, but code coverage can be unintuitive to
-newcomers, and especially so with Perl, so you may want to reconsider your
-expectations as well.
-
 Code coverage data are collected by replacing perl ops with functions which
 count how many times the ops are executed.  These data are then mapped back to
 reality using the B compiler modules.  There is also a statement profiling
 facility which should not be relied on.  For proper profiling use
-Devel::NYTProf.  Previous versions of Devel::Cover collected coverage data by
+L<Devel::NYTProf>.  Previous versions of Devel::Cover collected coverage data by
 replacing perl's runops function.  It is still possible to switch to that mode
 of operation, but this now gets little testing and will probably be removed
 soon.  You probably don't care about any of this.
 
 The most appropriate mailing list on which to discuss this module would be
-perl-qa.  Discussion has migrated there from perl-qa-metrics which is now
-defunct.  See L<http://lists.perl.org/list/perl-qa.html>.
+perl-qa.  See L<http://lists.perl.org/list/perl-qa.html>.
 
 The Devel::Cover repository can be found at
-L<http://github.com/pjcj/Devel--Cover>.
+L<http://github.com/pjcj/Devel--Cover>.  This is also where problems should be
+reported.
 
 =head1 REQUIREMENTS AND RECOMMENDED MODULES
 
@@ -1395,8 +1456,13 @@ L<http://github.com/pjcj/Devel--Cover>.
 Perl 5.7 is unsupported.  Perl 5.8.8 or greater is recommended.  Perl 5.8.7
 has problems and may crash.  Whilst Perl 5.6 should mostly work you will
 probably miss out on coverage information which would be available using a
-more modern version and will likely run into bugs in perl.  Different versions
-of perl may give slightly different results due to changes in the op tree.
+more modern version and will likely run into bugs in perl.  Devel::Cover
+support for unsupported Perl versions may be removed at any time, but I try to
+keep older versions running provided this does not cause undue difficulty i
+other areas.
+
+Different versions of perl may give slightly different results due to changes
+in the op tree.
 
 =item * The ability to compile XS extensions.
 
@@ -1435,12 +1501,16 @@ Some of Devel::Cover's own tests require it.
 
 =item * L<Test::Differences>
 
-if the tests fail and you would like nice output telling you why.
+Needed if the tests fail and you would like nice output telling you why.
 
-=item * L<Template>, and L<Parallel::Iterator>
+=item * L<Template> and L<Parallel::Iterator>
 
 Needed if you want to run cpancover.
 
+=item * L<JSON>, L<JSON::PP> or L<JSON::XS>
+
+JSON is used to store the coverage database if it is available.
+
 =back
 
 =head2 Use with mod_perl
@@ -1463,8 +1533,8 @@ information as possible.
                        cwd).
  -ignore RE          - Set REs of files to ignore (default "/Devel/Cover\b").
  +ignore RE          - Append to REs of files to ignore.
- -inc path           - Set prefixes of files to ignore (default @INC).
- +inc path           - Append to prefixes of files to ignore.
+ -inc path           - Set prefixes of files to include (default @INC).
+ +inc path           - Append to prefixes of files to include.
  -merge val          - Merge databases, for multiple test benches (default on).
  -select RE          - Set REs of files to select (default none).
  +select RE          - Append to REs of files to select.
@@ -1477,8 +1547,8 @@ information as possible.
 
 You can specify options to some coverage criteria.  At the moment only pod
 coverage takes any options.  These are the parameters which are passed into
-the Pod::Coverage constructor.  The extra options are separated by dashes, and
-you may specify as many as you wish.  For example, to specify that all
+the L<Pod::Coverage> constructor.  The extra options are separated by dashes,
+and you may specify as many as you wish.  For example, to specify that all
 subroutines containing xx are private, call Devel::Cover with the option
 -coverage,pod-also_private-xx.
 
@@ -1517,33 +1587,176 @@ multiple times, but they can also take multiple comma separated arguments.  In
 any case you should not add a space after the comma, unless you want the
 argument to start with that literal space.
 
+=head1 UNCOVERABLE CRITERIA
+
+Sometimes you have code which is uncoverable for some reason.  Perhaps it is
+an else clause that cannot be reached, or a check for an error condition that
+should never happen.  You can tell Devel::Cover that certain criteria are
+uncoverable and then they are not counted as errors when they are not
+exercised.  In fact, they are counted as errors if they are exercised.
+
+This feature should only be used as something of a last resort.  Ideally you
+would find some way of exercising all your code.  But if you have analysed
+your code and determined that you are not going to be able to exercise it, it
+may be better to record that fact in some formal fashion and stop Devel::Cover
+complaining about it, so that real problems are not lost in the noise.
+
+There are two ways to specify a construct as uncoverable, one invasive and one
+non-invasive.
+
+=head2 Invasive specification
+
+You can use special comments in your code to specify uncoverable criteria.
+Comments are of the form:
+
+ # uncoverable <criterion> [details]
+
+The keyword "uncoverable" must be the first text in the comment.  It should be
+followed by the name of the coverage criterion which is uncoverable.  There
+may then be further information depending on the nature of the uncoverable
+construct.
+
+=head3 Statements
+
+The "uncoverable" comment should appear on either the same line as the
+statement, of on the line before it:
+
+    $impossible++;  # uncoverable statement
+    # uncoverable statement
+    it_has_all_gone_horribly_wrong();
+
+If there are multiple statements (or any other criterion) on a line you can
+specify which statement is uncoverable by using the "count" attribute,
+count:n, which indicates that the uncoverable statement is the nth statement
+on the line.
+
+    # uncoverable statement count:1
+    # uncoverable statement count:2
+    cannot_run_this(); or_this();
+
+=head3 Branches
+
+The "uncoverable" comment should specify whether the "true" or "false" branch
+is uncoverable.
+
+    # uncoverable branch true
+    if (pi == 3)
+
+Both branches may be uncoverable:
+
+    # uncoverable branch true
+    # uncoverable branch false
+    if (impossible_thing_happened_one_way()) {
+        handle_it_one_way();      # uncoverable statement
+    } else {
+        handle_it_another_way();  # uncoverable statement
+    }
+
+=head3 Conditions
+
+Because of the way in which Perl short-circuits boolean operations, there are
+three ways in which such conditionals can be uncoverable.  In the case of C<
+$x && $y> for example, the left operator may never be true, the right operator
+may never be true, and the whole operation may never be false.  These
+conditions may be modelled thus:
+
+    # uncoverable branch true
+    # uncoverable condition left
+    # uncoverable condition false
+    if ($x && !$y)
+    {
+        $x++;  # uncoverable statement
+    }
+
+    # uncoverable branch true
+    # uncoverable condition right
+    # uncoverable condition false
+    if (!$x && $y)
+    {
+    }
+
+C<Or> conditionals are handled in a similar fashion (TODO - provide some
+examples) but C<xor> conditionals are not properly handled yet.
+
+=head3 Subroutines
+
+A subroutine should be marked as uncoverable at the point where the first
+statement is marked as uncoverable.  Ideally all other criteria in the
+subroutine would be marked as uncoverable automatically, but that isn't the
+case at the moment.
+
+    sub z
+    {
+        # uncoverable subroutine
+        $y++; # uncoverable statement
+    }
+
+=head2 Non-invasive specification
+
+If you can't, or don't want to add coverage comments to your code, you can
+specify the uncoverable information in a separate file.  My default this file
+is L<.uncoverable> but you can override that.
+
+The interface to managing this file is the L<cover> program, and the options
+are:
+
+ -uncoverable_file
+ -add_uncoverable_point
+ -delete_uncoverable_point
+ -clean_uncoverable_points
+
+Of these, only the first two are implemented at the moment.  The parameter for
+-add_uncoverable_point is a string composed of up to seven space separated
+elements: "$file $criterion $line $count $type $class $note".
+
+TODO - more information and examples.
+
 =head1 ENVIRONMENT
 
+=head2 User variables
+
 The -silent option is turned on when Devel::Cover is invoked via
 $HARNESS_PERL_SWITCHES or $PERL5OPT.  Devel::Cover tries to do the right thing
 when $MOD_PERL is set.  $DEVEL_COVER_OPTIONS is appended to any options passed
 into Devel::Cover.
 
+=head2 Developer variables
+
 When running Devel::Cover's own test suite, $DEVEL_COVER_DEBUG turns on
 debugging information, $DEVEL_COVER_GOLDEN_VERSION overrides Devel::Cover's
 own idea of which golden results it should test against, and
-$DEVEL_COVER_NO_COVERAGE runs the tests without collecting coverage.  The
-environment variables described in this paragraph are of interest to
-Devel::Cover maintainers only.
+$DEVEL_COVER_NO_COVERAGE runs the tests without collecting coverage.
+$DEVEL_COVER_DB_FORMAT may be set to either "JSON" or "Storable" to override
+the default choice of DB format (JSON if available, otherwise Storable).
+$DEVEL_COVER_IO_OPTIONS provides fine-grained control over the DB format.  For
+example, setting it to "pretty" when the format is JSON will store the DB in a
+readable JSON format.
 
 =head1 ACKNOWLEDGEMENTS
 
 Some code and ideas cribbed from:
 
- Devel::OpProf
- B::Concise
- B::Deparse
+=over 4
+
+=item * L<Devel::OpProf>
+
+=item * L<B::Concise>
+
+=item * L<B::Deparse>
+
+=back
 
 =head1 SEE ALSO
 
- Devel::Cover::Tutorial
- B
- Pod::Coverage
+=over 4
+
+=item * L<Devel::Cover::Tutorial>
+
+=item * L<B>
+
+=item * L<Pod::Coverage>
+
+=back
 
 =head1 LIMITATIONS
 
@@ -1579,23 +1792,23 @@ Modules used by Devel::Cover while gathering coverage:
 
 =over 4
 
-=item * B
+=item * L<B>
 
-=item * B::Debug
+=item * L<B::Debug>
 
-=item * B::Deparse
+=item * L<B::Deparse>
 
-=item * Carp
+=item * L<Carp>
 
-=item * Cwd
+=item * L<Cwd>
 
-=item * Digest::MD5
+=item * L<Digest::MD5>
 
-=item * File::Path
+=item * L<File::Path>
 
-=item * File::Spec
+=item * L<File::Spec>
 
-=item * Storable
+=item * L<Storable> or L<JSON>
 
 =back
 
@@ -1610,12 +1823,14 @@ CV.  Hints, tips or patches to resolve this will be gladly accepted.
 Almost certainly.
 
 See the BUGS file, the TODO file and the bug trackers at
-https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Cover and
-https://github.com/pjcj/Devel--Cover/issues?sort=created&direction=desc&state=open
+L<https://github.com/pjcj/Devel--Cover/issues?sort=created&direction=desc&state=open>
+and L<https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Cover>
+
+Please report new bugs on Github.
 
 =head1 LICENCE
 
-Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
