@@ -1,4 +1,4 @@
-# Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 use Devel::Cover::Criterion;
 use Devel::Cover::DB::File;
@@ -29,7 +29,9 @@ my $DB = "cover.13";  # Version 13 of the database.
 @Devel::Cover::DB::Criteria_short =
     (qw( stmt      bran   path cond      sub        pod time ));
 $Devel::Cover::DB::Ignore_filenames =
-    qr/   # Moose
+    qr/   # Used by Devel::Cover
+        (?: [\/\\]lib[\/\\](?:Storable|POSIX).pm$ )
+        | # Moose
         (?:
             (?:
                 reader | writer | constructor | destructor | accessor |
@@ -46,6 +48,8 @@ $Devel::Cover::DB::Ignore_filenames =
         (?: (?: rw-accessor | ro-accessor ) \s for )
         | # Template Toolkit
         (?: Parser\.yp )
+        | # perl generated
+        (?: \/loader\/0x )
       /x;
 
 sub new
@@ -86,9 +90,13 @@ sub read
     my $self   = shift;
     my ($file) = @_;
 
-    my $io     = Devel::Cover::DB::IO->new;
-    my $db     = $io->read($file);
-    $self->{runs} = $db->{runs};
+    my $io = Devel::Cover::DB::IO->new;
+    my $db = eval { $io->read($file) };
+    if ($@ or !$db) {
+        warn $@;
+    } else {
+        $self->{runs} = $db->{runs};
+    }
     $self
 }
 
@@ -615,7 +623,7 @@ sub uncoverable
         # print STDERR "Reading $file\n";
         open my $fh, "<", $file or do
         {
-            warn "Devel::Cover: Can't open file $file: $!\n";
+            warn "Devel::Cover: Can't open $file: $!\n";
             next;
         };
         my $df = Digest::MD5->new;  # MD5 digest of the file
@@ -720,7 +728,8 @@ sub uncoverable_comments
     # Look for uncoverable comments
     open my $fh, "<", $file or do
     {
-        warn "Devel::Cover: Can't open file $file: $!\n";
+        # The warning should have already been given ...
+        # warn "Devel::Cover: Warning: can't open $file: $!\n";
         return;
     };
     my @waiting;
@@ -892,8 +901,9 @@ sub cover
     my $st = Devel::Cover::DB::Structure->new(base => $self->{base})->read_all;
     my @runs = sort { $self->{runs}{$b}{start} <=> $self->{runs}{$a}{start} }
                     keys %{$self->{runs}};
-    # print STDERR "runs: ", Dumper $self->{runs};
+    # print STDERR "runs: ", Dumper \@runs
 
+    my %warned;
     for my $run (@runs)
     {
         last unless $st;
@@ -937,8 +947,9 @@ sub cover
                 # print STDERR "$criterion: ", Dumper $sc, $fc;
                 unless ($sc)
                 {
-                    print STDERR "Devel::Cover: Can't locate structure for ",
-                                 "$criterion in $file\n";
+                    print STDERR "Devel::Cover: Warning: can't locate ",
+                                 "structure for $criterion in $file\n"
+                        unless $warned{$file}{$criterion}++;
                     next;
                 }
                 my $cc  = $cf->{$criterion} ||= {};
@@ -960,11 +971,19 @@ sub cover
     $self->{cover}
 }
 
+sub run_keys
+{
+    my $self = shift;
+    $self->cover unless $self->{cover_valid};
+    sort { $self->{runs}{$b}{start} <=> $self->{runs}{$a}{start} }
+         keys %{$self->{runs}};
+}
+
 sub runs
 {
     my $self = shift;
     $self->cover unless $self->{cover_valid};
-    values %{$self->{runs}}
+    @{$self->{runs}}{$self->run_keys}
 }
 
 package Devel::Cover::DB::Run;
@@ -993,7 +1012,7 @@ Devel::Cover::DB - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 0.93
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -1001,7 +1020,6 @@ version 0.93
 
  my $db = Devel::Cover::DB->new(db => "my_coverage_db");
  $db->print_summary([$file1, $file2], ["statement", "pod"]);
- $db->print_details;
 
 =head1 DESCRIPTION
 
@@ -1083,7 +1101,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
