@@ -1,4 +1,4 @@
-# Copyright 2011-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,14 +10,14 @@ package Devel::Cover::DB::IO;
 use strict;
 use warnings;
 
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 my $Format;
 
 BEGIN
 {
     $Format = "JSON"     if              eval "use JSON; 1";
-    $Format = "JSON"     if !$Format and eval "use JSON:PP; 1";
+    $Format = "JSON"     if !$Format and eval "use JSON::PP; 1";
     $Format = "Storable" if !$Format and eval "use Storable; 1";
     die "Can't load either JSON or Storable" unless $Format;
 }
@@ -46,7 +46,7 @@ Devel::Cover::DB::IO - IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 0.93
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -76,7 +76,7 @@ Contructs the IO object.
 
  my $data = $io->read($file);
 
-Returns a perl data structure representingthe data read from $file.
+Returns a perl data structure representing the data read from $file.
 
 =head2 write
 
@@ -90,7 +90,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
