@@ -1,4 +1,4 @@
-# Copyright 2011-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -12,7 +12,7 @@ use warnings;
 
 use Fcntl ":flock";
 
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 my $Format;
 
@@ -35,13 +35,17 @@ sub read
     my $self   = shift;
     my ($file) = @_;
 
-    open my $fh, "<", $file or die "Can't open $file: $!";
-    flock($fh, LOCK_SH) or die "Cannot lock file: $!\n";
+    open my $fh, "<", $file or die "Can't open $file: $!\n";
+    flock $fh, LOCK_SH      or die "Can't lock $file: $!\n";
     local $/;
-    my $data = $Format eq "JSON"
-        ? JSON::decode_json(<$fh>)
-        : JSON::PP::decode_json(<$fh>);
-    close $fh or die "Can't close $file: $!";
+    my $data;
+    eval {
+        $data = $Format eq "JSON"
+            ? JSON::decode_json(<$fh>)
+            : JSON::PP::decode_json(<$fh>);
+    };
+    die "Can't read $file with $Format: $@" if $@;
+    close $fh or die "Can't close $file: $!\n";
     $data
 }
 
@@ -53,10 +57,10 @@ sub write
     my $json = $Format eq "JSON" ? JSON->new : JSON::PP->new;
     $json->utf8->allow_blessed;
     $json->ascii->pretty->canonical if $self->{options} =~ /\bpretty\b/i;
-    open my $fh, ">", $file or die "Can't open $file: $!";
-    flock($fh, LOCK_EX) or die "Cannot lock file: $!\n";
+    open my $fh, ">", $file or die "Can't open $file: $!\n";
+    flock $fh, LOCK_EX      or die "Can't lock $file: $!\n";
     print $fh $json->encode($data);
-    close $fh or die "Can't close $file: $!";
+    close $fh or die "Can't close $file: $!\n";
     $self
 }
 
@@ -70,7 +74,7 @@ Devel::Cover::DB::IO::JSON - JSON based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 0.93
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -100,7 +104,7 @@ Contructs the IO object.
 
  my $data = $io->read($file);
 
-Returns a perl data structure representingthe data read from $file.
+Returns a perl data structure representing the data read from $file.
 
 =head2 write
 
@@ -114,7 +118,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
