@@ -1,4 +1,4 @@
-# Copyright 2004-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2004-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -20,16 +20,13 @@ use Devel::Cover::Dumper;
 # For comprehensive debug logging.
 use constant DEBUG => 0;
 
-our $VERSION = '0.96'; # VERSION
+our $VERSION = '1.08'; # VERSION
 our $AUTOLOAD;
 
 sub new
 {
     my $class = shift;
-    my $self  =
-    {
-        @_
-    };
+    my $self  = { @_ };
     bless $self, $class
 }
 
@@ -51,11 +48,7 @@ sub AUTOLOAD
         my $c = $criterion eq "time" ? "statement" : $criterion;
         if (grep $_ eq $c, qw( sub_name file line ))
         {
-            *$func = sub
-            {
-                my $self = shift;
-                $self->{$c}
-            }
+            *$func = sub { shift->{$c} };
         }
         else
         {
@@ -94,7 +87,7 @@ sub debuglog {
 
     local $\;
     # One log file per process, as we're potentially dumping out large amounts,
-    # and might excede the atomic write size of the OS.
+    # and might exceed the atomic write size of the OS.
     open my $fh, '>>', "$dir/$$" or confess "Can't open $dir/$$: $!";
     print $fh "----------------" . gmtime() . "----------------\n";
     print $fh ref $_ ? Dumper($_) : $_;
@@ -232,6 +225,7 @@ sub digest
         print STDERR "Devel::Cover: Warning: can't open $file " .
                                              "for MD5 digest: $!\n"
             unless lc $file eq "-e" or
+                      $Devel::Cover::Silent or
                       $file =~ $Devel::Cover::DB::Ignore_filenames;
         # require "Cwd"; warn Carp::longmess("in " . Cwd::cwd());
     }
@@ -279,7 +273,9 @@ sub write
     for my $file (sort keys %{$self->{f}})
     {
         $self->{f}{$file}{file} = $file;
-        unless ($self->{f}{$file}{digest})
+        my $digest = $self->{f}{$file}{digest};
+        $digest = $1 if defined $digest && $digest =~ /(.*)/; # ie tainting.
+        unless ($digest)
         {
             warn "Can't find digest for $file"
                 unless $Devel::Cover::Silent ||
@@ -288,11 +284,10 @@ sub write
                         $file =~ q|/Devel/Cover[./]|);
             next;
         }
-        my $df_final = "$dir/$self->{f}{$file}{digest}";
-        my $df_temp = "$dir/.$self->{f}{$file}{digest}.$$";
+        my $df_final = "$dir/$digest";
+        my $df_temp = "$dir/.$digest.$$";
         # TODO - determine if Structure has changed to save writing it.
         # my $f = $df; my $n = 1; $df = $f . "." . $n++ while -e $df;
-        # print STDERR "Writing [$file] to [$df]\n";
         my $io = Devel::Cover::DB::IO->new;
         $io->write($self->{f}{$file}, $df_temp); # unless -e $df;
         unless (rename $df_temp, $df_final) {
@@ -377,6 +372,7 @@ sub read_all
     opendir D, $dir or return;
     for my $d (sort grep $_ !~ /\./, readdir D)
     {
+        $d = $1 if $d =~ /(.*)/; # Die tainting.
         $self->read($d);
     }
     closedir D or die "Can't closedir $dir: $!";
@@ -393,7 +389,7 @@ Devel::Cover::DB::Structure - Internal: abstract structure of a source file
 
 =head1 VERSION
 
-version 0.96
+version 1.08
 
 =head1 SYNOPSIS
 
@@ -414,7 +410,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2004-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2004-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
