@@ -1,4 +1,4 @@
-# Copyright 2002-2012, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2013, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Test;
 use strict;
 use warnings;
 
-our $VERSION = '0.93'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 use Carp;
 
@@ -218,13 +218,21 @@ sub run_test
     }
 
     my $version = int(($] - 5) * 1000 + 0.5);
-    if ($version % 2 && $version < 16)
+    if ($version % 2 && $version < 18)
     {
         Test::plan tests => 1;
         Test::skip("Perl version $] is an obsolete development version", 1);
         return;
     }
 
+    if ($] > 5.019001 && $] < 5.019004)
+    {
+        Test::plan tests => 1;
+        Test::skip("Perl version $] contains a bug which causes this test " .
+                   "to fail", 1);
+        return;
+    }
+
     my ($base, $v) = $self->cover_gold;
     return 1 unless $v;  # assume we are generating the golden results
     my $gold = "$base.$v";
@@ -426,7 +434,7 @@ Devel::Cover::Test - Internal module for testing
 
 =head1 VERSION
 
-version 0.93
+version 1.08
 
 =head1 METHODS
 
@@ -525,7 +533,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2012, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2013, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
